SettingsDelegate class abstract

Delegate interface for providing custom storage mechanisms.

Constructors

SettingsDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

backup(SettingsWriteRequest request) bool
Backup a setting.
cache(SettingsReadRequest request) Object?
Fetch a cached value for a setting.
clean() Future<void>
Clean all settings in storage.
get() Future<SettingsBackupResponse>
Fetch all settings from storage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(SettingsWriteRequest request) Future<void>
Set a value in storage.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited