SettingsReadRequest class

Represents a request to read a setting from storage.

Constructors

SettingsReadRequest({required String path, required Object? defaultValue, required DataType type, required Object? options})
Private constructor used internally.
const

Properties

defaultValue → Object?
Default value to return if the setting is missing.
final
hashCode → int
The hash code for this object.
no setterinherited
options → Object?
Optional additional options for reading.
final
path → String
Path or key of the setting.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DataType
Expected data type of the setting.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited