SettingsWriteRequest class
Represents a request to write a setting to storage.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → Object?
-
Optional additional options for writing.
final
- path → String
-
Path or key of the setting.
final
-
props
→ Map<
String, dynamic> -
All current properties for context.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DataType
-
Detected type of the value.
final
- value → Object?
-
Value to write.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited